@@ -23,30 +23,43 @@ def main(args):
     current2 = '/tmp/' + prefix + '.current2.fastq'
     fasta2fastq(args.fasta, current1)
     corrected = {}
+    correction_tries = defaultdict(int)
+    prev_tries = sum(correction_tries.values())
     rounds = 0
 
     print_time('Correcting input sequences with minimap2')
-    print_time('round\t#corrected\tmismatches\tindels\terrors')
+    print_time('round\tcorrectedFull\tcorrectedPartial\tmismatches\tindels\terrors')
     while True:
         rounds += 1
-        mLen, iLen, oLen, corrected_thisround, nErrors = iterate(args, rounds, prefix, current1, current2, corrected, identity_threshold = args.identity_threshold, mismatch_size_threshold = args.mismatch_size_threshold, indel_size_threshold = args.indel_size_threshold)
-        print_time('\t'.join(map(str, [rounds, len(corrected_thisround), iLen-mLen, oLen-iLen, nErrors])))
+        mLen, iLen, oLen, corrected_thisround, nErrors = iterate(args, rounds, prefix, current1, current2, corrected, correction_tries,
+                                                                 identity_threshold = args.identity_threshold,
+                                                                 mismatch_size_threshold = args.mismatch_size_threshold,
+                                                                 indel_size_threshold = args.indel_size_threshold)
         for b in corrected_thisround:
             if b not in corrected:
                 corrected[b] = set()
             corrected[b].update(corrected_thisround[b])
         call(['mv', current2, current1])
-        if not corrected_thisround and rounds >= args.correction_repeats_min:
+
+        current_tries = sum(correction_tries.values())
+        corrected_partial = current_tries - prev_tries
+
+        print_time('\t'.join(map(str, [rounds, len(corrected_thisround), corrected_partial, iLen-mLen, oLen-iLen, nErrors])))
+
+        if not corrected_thisround and not corrected_partial and rounds >= args.correction_repeats_min:
             # In some cases we report no corrected_thisround because fullCorrection = False for all sequences
             # We actually had corrected parts of them, and we will properly correct them in later rounds
             # correction_repeats_min ensures that we will try enough in order to get to fullCorrection = True and progress from there
+            # in some cases we also reach correction_repeats_min without doing any full correction. we check with corrected_partial
             break
         if rounds == args.correction_repeats:
             break
+        prev_tries = current_tries
+
     fastq2fasta(current1, args.output)
 
 
-def iterate(args, rounds, prefix, infastq, outfastq, corrected_previously, identity_threshold, mismatch_size_threshold, indel_size_threshold):
+def iterate(args, rounds, prefix, infastq, outfastq, corrected_previously, correction_tries, identity_threshold, mismatch_size_threshold, indel_size_threshold):
 
     seqOrderOriginal = []
     seqs = read_fastq(infastq)
@@ -74,7 +87,7 @@ def iterate(args, rounds, prefix, infastq, outfastq, corrected_previously, ident
     fLen = sum(len(s) for s in seqs.values())
 
     for i, target0 in enumerate(sortedSeqs):
-        
+
         if target0 in corrected_thisround or target0 in correctedSeqs:
             continue
 
@@ -88,14 +101,13 @@ def iterate(args, rounds, prefix, infastq, outfastq, corrected_previously, ident
         if not querybuf:
             continue
         
+        
         targetbuf.append(target0)
 
         tLen = sum(len(seqs[target]) for target in targetbuf)
         qLen = sum(len(seqs[query]) for query in querybuf)
 
         if tLen * qLen < 200 * fLen * len(seqs) and i+1 < len(sortedSeqs):
-        #if qLen < len(seqs):
-        #if len(targetbuf) * len(querybuf) < 1000000 and i+1 < len(sortedSeqs):
             continue
 
         queries = [n for n in sortedSeqs if n in querybuf]
@@ -142,6 +154,9 @@ def iterate(args, rounds, prefix, infastq, outfastq, corrected_previously, ident
             if sum([L for L, op in cigar if op == '=']) / idlen < identity_threshold:
                 continue # too many mismatches, ignore (indels are not counted here)
 
+##            if sum([L for L, op in cigar if op == '=']) / alignLen < identity_threshold:
+##                continue # too mamy mismatches and indels
+
             assert targetLen >= queryLen
 
             overlaps[target][query].append( ( queryStart, queryEnd, targetStart, targetEnd, cigar, isRC, matches, idlen, alignLen) )
@@ -194,8 +209,11 @@ def iterate(args, rounds, prefix, infastq, outfastq, corrected_previously, ident
                     correctedSeq.append( seqs[query][lastEnd:-1] )
 
                     correctedSeqs[query] = ''.join(correctedSeq)
-                    if fullCorrection:
+                    if fullCorrection or correction_tries[(query, target)] == 5:
+                        # we'll try to achieve full correction in 5 rounds, otherwise we'll consider it as corrected so we can use it as a template
                         corrected_thisround[query] = {target}
+                    else:
+                        correction_tries[(query, target)] += 1
 
                 except AssertionError: # we failed some assertion in correct_query. I checked a case and it was actually because the alignment/CIGAR string generated by minimap2 was wrong
                     nErrors += 1        # so we just ignore this correction completely
