@@ -21,7 +21,7 @@ from glob import glob
 
 print(f'\nAssuming that minimap2 can be found in the following path "{MINIMAP2_PATH}". Otherwise edit the MINIMAP2_PATH variable in this script\n')
 
-ecode = call([superpath,'-f'] + glob(f'{datapath}/*fna') + ['--assume-complete', '-t', '12', '--force-overwrite', '-o', output_path, '--minimap2-path', MINIMAP2_PATH])
+ecode = call([superpath,'-f'] + glob(f'{datapath}/*fna') + ['--assume-complete', '-t', '12', '--force-overwrite', '-o', output_path, '--minimap2-path', MINIMAP2_PATH, '--keep-intermediate'])
 
 if not ecode:
     print(f'\n\nAll went well, I hope! Test results should be present in {output_path}\n')
